/*
 * Copyright (C) 2002-2004 the xine-project
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 *
 * $Id: infobar.h,v 1.3 2004/11/26 22:57:01 dsalt Exp $
 *
 * a nice black information display area
 */
#ifndef HAVE_INFOBAR_H
#define HAVE_INFOBAR_H

#include <gtk/gtk.h>

typedef struct infobar_s infobar_t;

infobar_t *create_infobar (GtkWidget **w);

void postinit_infobar (GtkWidget *window, infobar_t *bar) ;

void infobar_show_metadata (void);

void infobar_clear (infobar_t *bar);
void infobar_line (infobar_t *bar, unsigned int lineno,
		   const char *format, ...);

#endif
